package com.glxp.udi.admin.config;

import com.glxp.udi.admin.service.udidl.UdidlService;
import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonElement;
import com.google.gson.JsonSerializationContext;
import feign.Contract;
import feign.Feign;
import feign.Request;
import feign.Retryer;
import feign.jackson.JacksonDecoder;
import feign.jackson.JacksonEncoder;
import lombok.val;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.concurrent.TimeUnit;

@Configuration
public class FeignConfiguration {
    @Autowired
    private GlobalConfig globalConfig;
    @Bean
    public Contract feignContract() {
        return new Contract.Default();
    }
    @Bean
    public UdidlService connect(){
        return Feign.builder()
                .encoder(new JacksonEncoder())
                .decoder(new JacksonDecoder())
                .options(this.options())
                .retryer(new Retryer.Default(5000,5000,3))
                .requestInterceptor(template -> template.header("Content-Type","application/json").
                        header("key",globalConfig.getUDI_SERVER_Key()))
                .target(UdidlService.class,globalConfig.getUDI_SERVER_URL());
    }
    private Request.Options options(){
        return new Request.Options(globalConfig.getUDI_SERVER_ConnectTimeout(), TimeUnit.SECONDS,
                globalConfig.getUDI_SERVER_ReadTimeout(),TimeUnit.SECONDS,globalConfig.isUDI_SERVER_FollowRedirects());
    }


}
