package com.glxp.udi.admin.controller.info;

import com.github.pagehelper.PageInfo;
import com.glxp.udi.admin.annotation.AuthRuleAnnotation;
import com.glxp.udi.admin.entity.info.PlatformEntity;
import com.glxp.udi.admin.exception.JsonException;
import com.glxp.udi.admin.res.PageSimpleResponse;
import com.glxp.udi.admin.service.info.PlatformService;
import com.glxp.udi.admin.util.UuidUtils;
import com.glxp.udi.common.enums.ResultEnum;
import com.glxp.udi.common.res.BaseResponse;
import com.glxp.udi.common.util.ResultVOUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;
import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSON;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

@RestController
@Slf4j
public class PlatformController {

    @Resource
    private PlatformService platformService;
  
    @AuthRuleAnnotation("")
    @PostMapping("/udims/platform/remove")
    public BaseResponse remove(@RequestBody PlatformEntity platformEntity) {
        if(platformService.remove(platformEntity.getId())>0)
        	ResultVOUtils.success("删除成功");
        return ResultVOUtils.error(500, "删除失败");
    }


    @AuthRuleAnnotation("")
    @PostMapping("/udims/platform/update")
    public BaseResponse update(@RequestBody PlatformEntity platformEntity) {
    	if(platformService.update(platformEntity)>0)
        	ResultVOUtils.success("修改成功");
        
        return ResultVOUtils.success("修改失败");
    }

    @AuthRuleAnnotation("")
    @GetMapping("/udims/platform/list")
    public BaseResponse list(@RequestParam Map<String, Object> params) {
        List<PlatformEntity> list = platformService.list(params);
        if(params.get("page")!=null&&params.get("limit")!=null) {
        	params.put("offset",(Integer.valueOf(params.get("page").toString()) -1) *(Integer.valueOf(params.get("limit").toString())));
        }
        int total = platformService.count(params);
        PageSimpleResponse<PlatformEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(Long.valueOf(String.valueOf(total)));
        pageSimpleResponse.setList(list);
        
        return ResultVOUtils.success(pageSimpleResponse);
    }


}
